package com.asset.common;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/*
 * @author xiaol
 * @date 2019/12/30
 */
public class Excel {

    private final static String excel2003L =".xls";    //2003- 版本的excel
    private final static String excel2007U =".xlsx";   //2007+ 版本的excel

    public Excel() {
        }

    /*
     *导入相关函数
     */
    public List<List<List<String>>> fileType(MultipartFile file) throws IOException {
        InputStream in = file.getInputStream();
        String fileName = file.getOriginalFilename();
        Workbook wb = null;
        String fileType = fileName.substring(fileName.lastIndexOf("."));
        try {
            if (excel2003L.equals(fileType)) {
                wb = new HSSFWorkbook(in);  //2003-
            } else if (excel2007U.equals(fileType)){
                wb = new XSSFWorkbook(in);  //2007+
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        List<List<List<String>>> listData = new ArrayList<>();
        Sheet sheet = null;
        for (int i=0;i<wb.getNumberOfSheets();i++){     //获取每个Sheet表
            sheet=wb.getSheetAt(i);
            //去掉空的Sheet
            if(sheet.getLastRowNum() == 0 &&  sheet.getPhysicalNumberOfRows() == 0){
                continue;
            }
            List<List<String>> sheetList = new ArrayList<>();
            for (int j=0;j<sheet.getPhysicalNumberOfRows();j++){    //获取每行
                XSSFRow row = (XSSFRow) sheet.getRow(j);
                //去掉空行和表头
                if (row == null || row.getFirstCellNum() == j) {
                    continue;
                }
                List<String> rowList = new ArrayList<String>();
                for (int k=0;k<row.getPhysicalNumberOfCells();k++){   //获取每个单元格
                    if(row.getCell(k)!=null){
                        Cell cell = row.getCell(k);
                        rowList.add(getValue(cell));
                    }
                }
                sheetList.add(rowList);
            }
            listData.add(sheetList);
        }
        wb.close();
        return listData;
    }

    /**
     * 判断每个单元格的数据类型
     */
    public static String getValue(Cell cell){
        if(cell.getCellType() == Cell.CELL_TYPE_STRING){
            return cell.getRichStringCellValue().getString();
        }else if(cell.getCellType() == Cell.CELL_TYPE_NUMERIC){
            if (DateUtil.isCellDateFormatted(cell)) {
                return String.valueOf(cell.getDateCellValue());
                /*Date d = cell.getDateCellValue();
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                value = sdf.format(d);*/
            } else {
                return String.valueOf(cell.getNumericCellValue());
            }
        }else if(cell.getCellType() == Cell.CELL_TYPE_BOOLEAN){
            return String.valueOf(cell.getBooleanCellValue());
        }else{
            return String.valueOf(cell.getStringCellValue());
        }
    }
    /*
    *导出相关函数
    */

    /**
     * 创建每个 sheet 页的数据
     */
    public void createSheetData(XSSFWorkbook aWorkbook, String[] aTitles, String aSheetName,
                                 List<String[]> aRowData) {
        XSSFSheet tmpSheet = aWorkbook.createSheet(aSheetName);
        // 设置sheet的标题
        XSSFRow tmpTitileRow = tmpSheet.createRow(0);
        for (int i = 0; i < aTitles.length; i++) {
            tmpTitileRow.createCell(i).setCellValue(aTitles[i]);
        }
        // 遍历填充每行的数据
        XSSFRow tmpRow = null;
        int tmpRowNumber = 1;
        for (String[] rowData : aRowData) {
            tmpRow = tmpSheet.createRow(tmpRowNumber);
            for (int i = 0; i < rowData.length; i++) {
                tmpRow.createCell(i).setCellValue(rowData[i]);
            }
            tmpRowNumber++;
        }
    }

    /**
     * 设置响应头
     */
    public void setResponseHeader(HttpServletResponse aResponse, String aFileName){
        try {
            try {
                aFileName = new String(aFileName.getBytes(), "ISO8859-1");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            aResponse.setContentType("application/octet-stream;charset=ISO8859-1");
            aResponse.setHeader("Content-Disposition", "attachment;filename=" + aFileName);
            aResponse.addHeader("Pargam", "no-cache");
            aResponse.addHeader("Cache-Control", "no-cache");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}