package com.asset.utils;

import com.asset.common.ResultUtil;
import com.asset.domain.Result;
import com.asset.enums.CodeEnum;
import org.springframework.boot.web.server.ConfigurableWebServerFactory;
import org.springframework.boot.web.server.ErrorPage;
import org.springframework.boot.web.server.WebServerFactory;
import org.springframework.boot.web.server.WebServerFactoryCustomizer;
import org.springframework.boot.web.servlet.server.ConfigurableServletWebServerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

@ControllerAdvice
public class GlableExceptionHandle {

    @ExceptionHandler(value = Exception.class)
    @ResponseBody
    public Result myExceptionHandler(Exception ex){
        return ResultUtil.error(CodeEnum.ERROR,ex.getMessage());
    }

    @Bean
    public WebServerFactoryCustomizer webServerFactoryCustomizer(){
        return new WebServerFactoryCustomizer<ConfigurableWebServerFactory>() {
            @Override
            public void customize(ConfigurableWebServerFactory factory) {
                ErrorPage error404Page = new ErrorPage(HttpStatus.NOT_FOUND, "/errorPage?code=10004");
                ErrorPage error400Page = new ErrorPage(HttpStatus.BAD_REQUEST, "/errorPage?code=10004");
                ErrorPage errorPage500 = new ErrorPage(HttpStatus.INTERNAL_SERVER_ERROR, "/errorPage?code=10004");
                factory.addErrorPages( error404Page,error400Page,errorPage500);
            }
        };
    }
}
